@@ -27,7 +27,6 @@ func init() {
 type Parser interface {
 	Parse() (*jsonx.Node, error)
 	Recover() *jsonx.Node
-	SkipWhitespace()
 }
 
 type Options struct {
@@ -52,6 +51,7 @@ func Start(parser Parser, args []string, opts Options) int {
 	if isPrettyPrintArg {
 		for {
 			node, err := parser.Parse()
+
 			if err != nil {
 				if err == io.EOF {
 					break
@@ -61,7 +61,7 @@ func Start(parser Parser, args []string, opts Options) int {
 			}
 
 			if node.Kind == jsonx.String {
-				unquoted, err := strconv.Unquote(string(node.Value))
+				unquoted, err := strconv.Unquote(node.Value)
 				if err != nil {
 					panic(err)
 				}
@@ -69,8 +69,6 @@ func Start(parser Parser, args []string, opts Options) int {
 			} else {
 				opts.WriteOut(pretty.Print(node, opts.WithInline))
 			}
-
-			parser.SkipWhitespace()
 		}
 
 		return 0
@@ -141,8 +139,6 @@ func Start(parser Parser, args []string, opts Options) int {
 			continue
 		}
 		echo(output)
-
-		parser.SkipWhitespace()
 	}
 
 	return 0
